@@ -27,7 +27,7 @@ HTTPCACHE_ENABLED = True
 
 HTTPCACHE_POLICY = 'scrapy.contrib.httpcache.RFC2616Policy'
 
-HTTPCACHE_STORAGE = 'scrapy.contrib.httpcache.DbmCacheStorage'
+HTTPCACHE_STORAGE = 'scrapy.contrib.httpcache.LeveldbCacheStorage'
 
 LOG_LEVEL = 'INFO'
 
@@ -37,3 +37,18 @@ SPIDER_MODULES = ['pystock_crawler.spiders']
 
 # Crawl responsibly by identifying yourself (and your website) on the user-agent
 #USER_AGENT = 'pystock-crawler (+http://www.yourdomain.com)'
+
+CONCURRENT_REQUESTS_PER_DOMAIN = 8
+
+COOKIES_ENABLED = False
+
+#AUTOTHROTTLE_ENABLED = True
+
+RETRY_TIMES = 4
+
+EXTENSIONS = {
+    'pystock_crawler.throttle.PassiveThrottle': 0
+}
+
+PASSIVETHROTTLE_ENABLED = True
+#PASSIVETHROTTLE_DEBUG = True
